@@ -6,6 +6,7 @@ from pyporscheconnectapi.exceptions import WrongCredentials
 import sys
 import logging
 import json
+from getpass import getpass
 
 logging.basicConfig()
 logging.root.setLevel(logging.WARNING)
@@ -20,7 +21,10 @@ async def main(args):
     except json.decoder.JSONDecodeError:
         tokens = {}
 
-    conn = Connection(args.email, args.password, tokens=tokens, country=args.country, language=args.language)
+    email = args.email or input("Please enter Porsche Connect email: ")
+    password = args.password or getpass()
+    conn = Connection(email, password, tokens=tokens, country=args.country, language=args.language)
+
     client = Client(conn)
 
     try:
@@ -41,7 +45,10 @@ async def main(args):
             for vin in vins:
                 data = {}
                 if args.command == "overview":
-                    data = await client.getOverview(vin)
+                    if(args.nowait):
+                        data = await client.getStoredOverview(vin)
+                    else:
+                        data = await client.getCurrentOverview(vin)
                 elif args.command == "maintenance":
                     data = await client.getMaintenance(vin)
                 elif args.command == "summary":
@@ -60,6 +67,23 @@ async def main(args):
                     data = await client.getSpeedAlerts(vin, country=args.country, language=args.language)
                 elif args.command == "theftalerts":
                     data = await client.getTheftAlerts(vin)
+                elif args.command == "climate-on":
+                    data = await client.climateOn(vin, waitForConfirmation = not args.nowait)
+                elif args.command == "climate-off":
+                    data = await client.climateOff(vin, waitForConfirmation = not args.nowait)
+                elif args.command == "directcharge-on":
+                    data = await client.directChargeOn(vin, model=args.model, waitForConfirmation = not args.nowait)
+                elif args.command == "directcharge-off":
+                    data = await client.directChargeOff(vin, model=args.model, waitForConfirmation = not args.nowait)
+                elif args.command == 'lock' or args.command == 'unlock':
+                    pin = args.pin
+                    if pin is None:
+                        pin = getpass("PIN code: ")
+                    if(args.command == 'lock'):
+                        data = await client.lock(vin, pin, waitForConfirmation = not args.nowait)
+                    else:
+                        data = await client.unlock(vin, pin, waitForConfirmation = not args.nowait)
+
                 print(json.dumps(data, indent=2))
     except WrongCredentials:
         sys.exit("Wrong email or password")
@@ -71,16 +95,19 @@ async def main(args):
 def cli():
     parser = argparse.ArgumentParser(description='Porsche Connect CLI.')
     parser.add_argument('command', choices=['list', 'overview', 'maintenance', 'summary', 'capabilities', 'emobility',
-        'position', 'triplongterm', 'tripshortterm', 'speedalerts', 'theftalerts', 'tokens'])
-    parser.add_argument('-e', '--email', dest='email', required=True)
-    parser.add_argument('-p', '--password', dest='password', required=True)
+        'position', 'triplongterm', 'tripshortterm', 'speedalerts', 'theftalerts', 'tokens', 'lock', 'unlock',
+        'climate-on', 'climate-off', 'directcharge-on', 'directcharge-off'])
+    parser.add_argument('-e', '--email', dest='email', default=None)
+    parser.add_argument('-p', '--password', dest='password', default=None)
     parser.add_argument('-s', '--sessionfile', dest='session_file', default='.session')
     parser.add_argument('-v', '--vin', dest='vin', default=None)
+    parser.add_argument('-n', '--pin', dest='pin', default=None)
     parser.add_argument('-m', '--model', dest='model', default=None)
     parser.add_argument('-a', '--all', dest='all', action='store_true')
     parser.add_argument('-c', '--country', dest='country', default='de')
     parser.add_argument('-l', '--language', dest='language', default='DE')
     parser.add_argument('-z', '--timezone', dest='timezone', default='Europe/Stockholm')
+    parser.add_argument('--nowait', dest='nowait', action='store_true')
 
     args = parser.parse_args()
 
