@@ -45,13 +45,14 @@ class Connection:
         self.porscheAPI: Text = "https://connect-portal.porsche.com/core/api/v3/de/de_DE"
         self.porscheApplications = {
                 'portal': {
+#                    'client_id': '4mPO3OE5Srjb1iaUGWsbqKBvvesya8oA',
                     'client_id': 'TZ4Vf5wnKeipJxvatJ60lPHYEzqZ4WNp',
                     'redirect_uri': 'https://my-static02.porsche.com/static/cms/auth.html',
                     'prefix': 'https://connect-portal.porsche.com/core/api/v3/'
                     },
                 'carcontrol': {
-                    'client_id': 'gZLSI7ThXFB4d2ld9t8Cx2DBRvGr1zN2',
-                    'redirect_uri':  'https://connect-portal.porsche.com/myservices/auth/auth.html',
+                    'client_id': 'imeVsv86TpjM9beWJqI0sNMAip6ga05O',
+                    'redirect_uri':  'https://my.porsche.com/myservices/auth/auth.html',
                     'prefix': 'https://api.porsche.com/'
                     }
                 }
